@@ -13,16 +13,13 @@ use warnings;
 use 5.006000;
 
 my @constants = qw/
-  GEARMAN_ALLOCATED
   GEARMAN_ARGS_BUFFER_SIZE
+  GEARMAN_ARGUMENT_TOO_LARGE
   GEARMAN_CLIENT_ALLOCATED
   GEARMAN_CLIENT_FREE_TASKS
+  GEARMAN_CLIENT_MAX
   GEARMAN_CLIENT_NON_BLOCKING
   GEARMAN_CLIENT_NO_NEW
-  GEARMAN_CLIENT_STATE_IDLE
-  GEARMAN_CLIENT_STATE_NEW
-  GEARMAN_CLIENT_STATE_PACKET
-  GEARMAN_CLIENT_STATE_SUBMIT
   GEARMAN_CLIENT_TASK_IN_USE
   GEARMAN_CLIENT_UNBUFFERED_RESULT
   GEARMAN_COMMAND_ALL_YOURS
@@ -63,24 +60,12 @@ my @constants = qw/
   GEARMAN_COMMAND_WORK_FAIL
   GEARMAN_COMMAND_WORK_STATUS
   GEARMAN_COMMAND_WORK_WARNING
-  GEARMAN_CON_ALLOCATED
   GEARMAN_CON_CLOSE_AFTER_FLUSH
   GEARMAN_CON_EXTERNAL_FD
   GEARMAN_CON_IGNORE_LOST_CONNECTION
+  GEARMAN_CON_MAX
   GEARMAN_CON_PACKET_IN_USE
   GEARMAN_CON_READY
-  GEARMAN_CON_RECV_STATE_NONE
-  GEARMAN_CON_RECV_STATE_READ
-  GEARMAN_CON_RECV_STATE_READ_DATA
-  GEARMAN_CON_SEND_STATE_FLUSH
-  GEARMAN_CON_SEND_STATE_FLUSH_DATA
-  GEARMAN_CON_SEND_STATE_FORCE_FLUSH
-  GEARMAN_CON_SEND_STATE_NONE
-  GEARMAN_CON_SEND_STATE_PRE_FLUSH
-  GEARMAN_CON_STATE_ADDRINFO
-  GEARMAN_CON_STATE_CONNECT
-  GEARMAN_CON_STATE_CONNECTED
-  GEARMAN_CON_STATE_CONNECTING
   GEARMAN_COULD_NOT_CONNECT
   GEARMAN_DATA_TOO_LARGE
   GEARMAN_DEFAULT_SOCKET_RECV_SIZE
@@ -101,21 +86,15 @@ my @constants = qw/
   GEARMAN_INVALID_PACKET
   GEARMAN_INVALID_WORKER_FUNCTION
   GEARMAN_IO_WAIT
-  GEARMAN_JOB_ALLOCATED
-  GEARMAN_JOB_ASSIGNED_IN_USE
   GEARMAN_JOB_EXISTS
-  GEARMAN_JOB_FINISHED
   GEARMAN_JOB_HANDLE_SIZE
   GEARMAN_JOB_PRIORITY_HIGH
   GEARMAN_JOB_PRIORITY_LOW
   GEARMAN_JOB_PRIORITY_MAX
   GEARMAN_JOB_PRIORITY_NORMAL
   GEARMAN_JOB_QUEUE_FULL
-  GEARMAN_JOB_WORK_IN_USE
   GEARMAN_LOST_CONNECTION
-  GEARMAN_MAGIC_REQUEST
-  GEARMAN_MAGIC_RESPONSE
-  GEARMAN_MAGIC_TEXT
+  GEARMAN_MAX
   GEARMAN_MAX_COMMAND_ARGS
   GEARMAN_MAX_ERROR_SIZE
   GEARMAN_MAX_RETURN
@@ -126,12 +105,10 @@ my @constants = qw/
   GEARMAN_NOT_FLUSHING
   GEARMAN_NO_ACTIVE_FDS
   GEARMAN_NO_JOBS
+  GEARMAN_NO_REGISTERED_FUNCTION
   GEARMAN_NO_REGISTERED_FUNCTIONS
   GEARMAN_NO_SERVERS
   GEARMAN_OPTION_SIZE
-  GEARMAN_PACKET_ALLOCATED
-  GEARMAN_PACKET_COMPLETE
-  GEARMAN_PACKET_FREE_DATA
   GEARMAN_PACKET_HEADER_SIZE
   GEARMAN_PAUSE
   GEARMAN_PIPE_EOF
@@ -146,20 +123,6 @@ my @constants = qw/
   GEARMAN_SHUTDOWN
   GEARMAN_SHUTDOWN_GRACEFUL
   GEARMAN_SUCCESS
-  GEARMAN_TASK_ALLOCATED
-  GEARMAN_TASK_SEND_IN_USE
-  GEARMAN_TASK_STATE_COMPLETE
-  GEARMAN_TASK_STATE_CREATED
-  GEARMAN_TASK_STATE_DATA
-  GEARMAN_TASK_STATE_EXCEPTION
-  GEARMAN_TASK_STATE_FAIL
-  GEARMAN_TASK_STATE_FINISHED
-  GEARMAN_TASK_STATE_NEW
-  GEARMAN_TASK_STATE_STATUS
-  GEARMAN_TASK_STATE_SUBMIT
-  GEARMAN_TASK_STATE_WARNING
-  GEARMAN_TASK_STATE_WORK
-  GEARMAN_TASK_STATE_WORKLOAD
   GEARMAN_TIMEOUT
   GEARMAN_TOO_MANY_ARGS
   GEARMAN_UNEXPECTED_PACKET
@@ -172,29 +135,18 @@ my @constants = qw/
   GEARMAN_VERBOSE_FATAL
   GEARMAN_VERBOSE_INFO
   GEARMAN_VERBOSE_MAX
+  GEARMAN_VERBOSE_NEVER
   GEARMAN_WORKER_ALLOCATED
   GEARMAN_WORKER_CHANGE
-  GEARMAN_WORKER_FUNCTION_CHANGE
-  GEARMAN_WORKER_FUNCTION_PACKET_IN_USE
-  GEARMAN_WORKER_FUNCTION_REMOVE
   GEARMAN_WORKER_GRAB_JOB_IN_USE
   GEARMAN_WORKER_GRAB_UNIQ
+  GEARMAN_WORKER_MAX
   GEARMAN_WORKER_NON_BLOCKING
   GEARMAN_WORKER_PACKET_INIT
   GEARMAN_WORKER_PRE_SLEEP_IN_USE
-  GEARMAN_WORKER_STATE_CONNECT
-  GEARMAN_WORKER_STATE_FUNCTION_SEND
-  GEARMAN_WORKER_STATE_GRAB_JOB_RECV
-  GEARMAN_WORKER_STATE_GRAB_JOB_SEND
-  GEARMAN_WORKER_STATE_PRE_SLEEP
-  GEARMAN_WORKER_STATE_START
   GEARMAN_WORKER_TIMEOUT_RETURN
   GEARMAN_WORKER_WAIT_TIMEOUT
   GEARMAN_WORKER_WORK_JOB_IN_USE
-  GEARMAN_WORKER_WORK_STATE_COMPLETE
-  GEARMAN_WORKER_WORK_STATE_FAIL
-  GEARMAN_WORKER_WORK_STATE_FUNCTION
-  GEARMAN_WORKER_WORK_STATE_GRAB_JOB
   GEARMAN_WORK_DATA
   GEARMAN_WORK_ERROR
   GEARMAN_WORK_EXCEPTION
@@ -208,7 +160,7 @@ our @EXPORT_OK = @constants;
 
 our @ISA;
 BEGIN {
-  our $VERSION= '0.7';
+  our $VERSION= '0.8';
 
   eval {
     require XSLoader;
@@ -238,6 +190,12 @@ More information is available at:
 
 It aims to provide a simple interface closely tied to the C library.
 
+=head1 METHODS
+
+=head2 Gearman::XS::strerror($ret)
+
+Return string translation of return code.
+
 =head1 BUGS
 
 Any in libgearman plus many others of my own.
